@@ -42,6 +42,12 @@ elif usrp_prims.usrp_usrp1_p (d):
     source_c = usrp1.source_c
     sink_s = usrp1.sink_s
     source_s = usrp1.source_s
+elif usrp_prims.usrp_usrp2_p (d):
+    print "usrp: found usrp rev2"
+    sink_c = usrp1.sink_c
+    source_c = usrp1.source_c
+    sink_s = usrp1.sink_s
+    source_s = usrp1.source_s
 else:
     raise RuntimeError, "Hmmm, unknown usrp rev"
 
